Solver dictionaries
===================

``backends.abstract_backend_dictionary``
-----------------------------------------------------------------------

.. automodule:: sage_numerical_interactive_mip.backends.abstract_backend_dictionary
   :members:
   :special-members:
   :private-members:
   :show-inheritance:

``backends.glpk_backend_dictionary``
-------------------------------------------------------------------

.. automodule:: sage_numerical_interactive_mip.backends.glpk_backend_dictionary
   :members:
   :special-members:
   :private-members:
   :show-inheritance:

``backends.coin_backend_dictionary``
-------------------------------------------------------------------

.. automodule:: sage_numerical_interactive_mip.backends.coin_backend_dictionary
   :members:
   :special-members:
   :private-members:
   :show-inheritance:

``clean_dictionary``
---------------------------------------------------

.. automodule:: sage_numerical_interactive_mip.clean_dictionary
   :members:
   :special-members:
   :private-members:
   :show-inheritance:
